==> lore-hook-dialogs-bootstrap-0.8.1.tgz: package/lib/blueprints/Destroy.js <==
'use strict';

var React = require('react');
var DialogMixin = require('../mixins/DialogMixin');

module.exports = function (options) {
  options = options || {};

  var title = options.title;
  var submitButtonText = options.submitButtonText;

  return React.createClass({
    displayName: 'Dialog',

    mixins: [DialogMixin],

    propTypes: {
      model: React.PropTypes.object.isRequired
    },

    render: function render() {
      return React.createElement(
        'div',
        { className: 'modal fade' },
        React.createElement(
          'div',
          { className: 'modal-dialog' },
          React.createElement(
            'div',
            { className: 'modal-content' },
            React.createElement(
              'div',
              { className: 'modal-header' },
              React.createElement(
                'button',
                { type: 'button', className: 'close', 'data-dismiss': 'modal' },
                React.createElement(
                  'span',
                  null,
                  '×'
                )
              ),
              React.createElement(
                'h4',
                { className: 'modal-title' },
                title
              )
            ),
            React.createElement(
              'div',
              { className: 'modal-body' },
              React.createElement(
                'form',
                null,
                React.createElement(
                  'div',
                  { className: 'form-group' },
                  React.createElement(
                    'label',
                    { className: 'control-label' },
                    'Are you sure you want to destroy this model?'
                  )
                )
              )
            ),
            React.createElement(
              'div',
              { className: 'modal-footer' },
              React.createElement(
                'button',
                { type: 'button', className: 'btn btn-default', 'data-dismiss': 'modal' },
                'Close'
              ),
              React.createElement(
                'button',
                { type: 'button', className: 'btn btn-primary', onClick: this.onSubmit },
                submitButtonText
              )
            )
          )
        )
      );
    }
  });
};

==> lore-hook-dialogs-bootstrap-0.9.0.tgz: package/lib/blueprints/Destroy.js <==
'use strict';

var React = require('react');
var DialogMixin = require('../mixins/DialogMixin');

module.exports = function (options) {
  options = options || {};

  var title = options.title;
  var cancelButtonText = options.cancelButtonText;
  var submitButtonText = options.submitButtonText;

  return React.createClass({
    displayName: 'Dialog',

    mixins: [DialogMixin],

    propTypes: {
      model: React.PropTypes.object.isRequired
    },

    getStyles: function getStyles() {
      return {
        form: {
          marginTop: '14px'
        }
      };
    },

    render: function render() {
      var styles = this.getStyles();

      return React.createElement(
        'div',
        { className: 'modal fade' },
        React.createElement(
          'div',
          { className: 'modal-dialog' },
          React.createElement(
            'div',
            { className: 'modal-content' },
            React.createElement(
              'div',
              { className: 'modal-header' },
              React.createElement(
                'button',
                { type: 'button', className: 'close', 'data-dismiss': 'modal' },
                React.createElement(
                  'span',
                  null,
                  '×'
                )
              ),
              React.createElement(
                'h4',
                { className: 'modal-title' },
                title
              )
            ),
            React.createElement(
              'div',
              { className: 'modal-body' },
              React.createElement(
                'form',
                { style: styles.form },
                React.createElement(
                  'p',
                  null,
                  'Are you sure you want to delete this?'
                )
              )
            ),
            React.createElement(
              'div',
              { className: 'modal-footer' },
              React.createElement(
                'button',
                { type: 'button', className: 'btn btn-default', 'data-dismiss': 'modal' },
                cancelButtonText
              ),
              React.createElement(
                'button',
                { type: 'button', className: 'btn btn-primary', onClick: this.onSubmit },
                submitButtonText
              )
            )
          )
        )
      );
    }
  });
};
